@@ -5,7 +5,7 @@ use warnings;
 package Dist::Zilla::Plugin::Test::ReportPrereqs;
 # ABSTRACT: Report on prerequisite versions during automated testing
 
-our $VERSION = '0.024';
+our $VERSION = '0.025';
 
 use Dist::Zilla 4 ();
 
@@ -223,7 +223,7 @@ Dist::Zilla::Plugin::Test::ReportPrereqs - Report on prerequisite versions durin
 
 =head1 VERSION
 
-version 0.024
+version 0.025
 
 =head1 SYNOPSIS
 
@@ -450,10 +450,10 @@ my $full_prereqs = _merge_prereqs(
 
 # Add dynamic prereqs to the included modules list (if we can)
 my ($source) = grep { -f } 'MYMETA.json', 'MYMETA.yml';
-if ( $source && $HAS_CPAN_META ) {
-    if ( my $meta = eval { CPAN::Meta->load_file($source) } ) {
-        $full_prereqs = _merge_prereqs($full_prereqs, $meta->prereqs);
-    }
+if ( $source && $HAS_CPAN_META
+    && (my $meta = eval { CPAN::Meta->load_file($source) } )
+) {
+    $full_prereqs = _merge_prereqs($full_prereqs, $meta->prereqs);
 }
 else {
     $source = 'static metadata';
